@@ -7,7 +7,7 @@ from .bed import _BedDataSet
 
 class BedRegionDataSet(_BedDataSet, ABC):
     """
-    The BedRegion ...
+    The BedRegion DataSet
     """
 
     SELECT_LABEL = (
@@ -26,7 +26,7 @@ class BedRegionDataSet(_BedDataSet, ABC):
             self, database, where, seq_length, label_func=label_func, **kwargs
         )
 
-    def array_from_query(
+    def _array_from_query(
         self,
         query: List[Tuple[int, int, int, int]],
         cur_chrom_id: int,
